@@ -5,11 +5,11 @@ This module does not contain docstrings for the wrapped code, check Apple's
 documentation for details on how to use these functions and classes.
 """
 
-import objc
 import sys
-import Cocoa
 
-from IMServicePlugIn import _metadata, _IMServicePlugIn
+import Cocoa
+import objc
+from IMServicePlugIn import _IMServicePlugIn, _metadata
 
 try:
     long
@@ -28,10 +28,9 @@ sys.modules["IMServicePlugIn"] = mod = objc.ObjCLazyModule(
         "__path__": __path__,
         "__loader__": globals().get("__loader__", None),
     },
-    (Cocoa,),
+    (_IMServicePlugIn, Cocoa),
 )
 
-import sys
 
 del sys.modules["IMServicePlugIn._metadata"]
 del sys.modules["IMServicePlugIn._IMServicePlugIn"]
