@@ -1,5 +1,5 @@
-from PyObjCTools.TestSupport import *
 import IMServicePlugIn
+from PyObjCTools.TestSupport import TestCase, expectedFailure
 import objc
 
 
@@ -15,7 +15,3 @@ class TestIMServicePlugInFileTransferSession(TestCase):
         self.assertIsInstance(
             IMServicePlugIn.IMServicePlugInIncomingFileTransferSession, objc.objc_class
         )
-
-
-if __name__ == "__main__":
-    main()
